@@ -22,13 +22,13 @@ class TestWriter(unittest.TestCase):
         file_name_cyclohexane = "./tests/molecules/cyclohexane.xyz"
 
         # case 1
-        coordinates = self.benzene.struct3D()
+        coordinates = self.benzene.get_3D_coordinates()
         write_xyz(self.benzene, file_name_benzene)
 
         assert os.path.isfile(file_name_benzene)
 
         # case 2
-        coordinates = self.cyclohexane.struct3D()
+        coordinates = self.cyclohexane.get_3D_coordinates()
         write_xyz(self.cyclohexane, file_name_cyclohexane)
 
         assert os.path.isfile(file_name_cyclohexane)
